@@ -5,8 +5,8 @@
 typedef enum __attribute__((__packed__)) FFSizeBinaryPrefixType
 {
     FF_SIZE_BINARY_PREFIX_TYPE_IEC,   // 1024 Bytes = 1 KiB, 1024 KiB = 1 MiB, ... (standard)
-    FF_SIZE_BINARY_PREFIX_TYPE_SI,    // 1000 Bytes = 1 KB, 1000 KB = 1 MB, ...
-    FF_SIZE_BINARY_PREFIX_TYPE_JEDEC, // 1024 Bytes = 1 kB, 1024 kB = 1 MB, ...
+    FF_SIZE_BINARY_PREFIX_TYPE_SI,    // 1000 Bytes = 1 kB, 1000 kB = 1 MB, ...
+    FF_SIZE_BINARY_PREFIX_TYPE_JEDEC, // 1024 Bytes = 1 KB, 1024 KB = 1 MB, ...
 } FFSizeBinaryPrefixType;
 
 typedef enum __attribute__((__packed__)) FFTemperatureUnit
@@ -32,6 +32,9 @@ typedef struct FFOptionsDisplay
     int32_t stat; // <0: disable stat; 0: no threshold; >0: threshold in ms
     bool pipe; //disables all escape sequences
     bool showErrors;
+    #ifndef NDEBUG
+    bool debugMode;
+    #endif
     bool disableLinewrap;
     bool hideCursor;
     FFSizeBinaryPrefixType sizeBinaryPrefix;
@@ -57,6 +60,7 @@ typedef struct FFOptionsDisplay
     uint16_t keyWidth;
     uint16_t keyPaddingLeft;
     int8_t freqNdigits;
+    int8_t fractionNdigits;
     FFlist constants; // list of FFstrbuf
 } FFOptionsDisplay;
 
